/*
 * Copyright 2016 - 2025 Gary Talent (gary@drinkingtea.net). All rights reserved.
 */

#include "commands.hpp"

#include "movecolorcommand.hpp"

namespace nostalgia::core {

MoveColorCommand::MoveColorCommand(
		Palette &pal, size_t page, size_t srcIdx, size_t dstIdx) noexcept:
	m_pal(pal),
	m_page(page),
	m_srcIdx(srcIdx),
	m_dstIdx(dstIdx) {}

int MoveColorCommand::commandId() const noexcept {
	return static_cast<int>(PaletteEditorCommandId::MoveColor);
}

ox::Error MoveColorCommand::redo() noexcept {
	moveColor(m_srcIdx, m_dstIdx);
	return {};
}

ox::Error MoveColorCommand::undo() noexcept {
	moveColor(m_dstIdx, m_srcIdx);
	return {};
}

void MoveColorCommand::moveColor(size_t srcIdx, size_t dstIdx) noexcept {
	auto const c = color(m_pal, m_page, srcIdx);
	std::ignore = colors(m_pal, m_page).erase(srcIdx);
	colors(m_pal, m_page).emplace(dstIdx, c);
}

}
